%%% 
%%% syllabus.cls
%%% LaTeX syllabus document class, based on:
%%%
%%%    This syllabus template was created by:
%%%    Brian R. Hall
%%%    Assistant Professor, Champlain College
%%%    www.brianrhall.net
%%%

\ProvidesClass{syllabus}[2012/08/16 Andrew Clifton]
\NeedsTeXFormat{LaTeX2e}[1999/09/01]

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\PassOptionsToClass{11pt}{article}
\ProcessOptions\relax

\LoadClass{article}

\RequirePackage[margin=1in]{geometry}
\RequirePackage{multirow}
\RequirePackage{setspace}
\RequirePackage{ifthen}
\RequirePackage{xifthen}
\RequirePackage{longtable}
\RequirePackage{hyperref}

% Logo text/image for univ/dept/college
\newcommand{\@schoollogo}{}

% Information about the course instructor(s)
\newcommand{\@profimage}{}
\newcommand{\@profname}{No Professor Name}
\newcommand{\@profemail}{No Professor Email}
\newcommand{\@profwebsite}{No Professor website}
\newcommand{\@profoffice}{No Professor Office Hours}
\newcommand{\@profhours}{No Professor Office Hours}
\newcommand{\@profphone}{No Professor ph\#}

% Information about the course itself
\newcommand{\@coursenum}{No Course Number}
\newcommand{\@coursetitle}{No Course Title}
\newcommand{\@coursesched}{No Course Schedule/Location}

% The "this syllabus is subject to change" text.
\newcommand{\@revisiontext}{%
This syllabus and schedule are subject to change in the event of extenuating 
circumstances. If you are absent from class, it is your responsibility to check 
on announcements made while you were absent.%
}

% Other course details
\newcommand{\@coursedescription}{No course description}
\newcommand{\@prereqs}{No course prerequisites}
%\newcommand{\@notes}{}
\newcommand{\@unittext}{Units}
\newcommand{\@units}{Number of Units}
\newcommand{\@textbooks}{No course textbooks}

\newcommand{\@policies}{Academic honesty policy: Don't cheat.}

\newcommand{\showpolicies}{\@policies}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newcommand{\schoollogo}[1]{\renewcommand{\@schoollogo}{#1}}
\newcommand{\profimage}[1]{\renewcommand{\@profimage}{#1}}
\newcommand{\profname}[1]{\renewcommand{\@profname}{#1}}
\newcommand{\profemail}[1]{\renewcommand{\@profemail}{#1}}
\newcommand{\profwebsite}[1]{\renewcommand{\@profwebsite}{#1}}
\newcommand{\profoffice}[1]{\renewcommand{\@profoffice}{#1}}
\newcommand{\profhours}[1]{\renewcommand{\@profhours}{#1}}
\newcommand{\profphone}[1]{\renewcommand{\@profphone}{#1}}
\newcommand{\coursenum}[1]{\renewcommand{\@coursenum}{#1}}
\newcommand{\coursetitle}[1]{\renewcommand{\@coursetitle}{#1}}
\newcommand{\coursesched}[1]{\renewcommand{\@coursesched}{#1}}
\newcommand{\revisiontext}[1]{\renewcommand{\@revisiontext}{#1}}
\newcommand{\coursedescription}[1]{\renewcommand{\@coursedescription}{#1}}
\newcommand{\prereqs}[1]{\renewcommand{\@prereqs}{#1}}
\newcommand{\notes}[1]{\providecommand{\@notes}{#1}}
\newcommand{\unittext}[1]{\renewcommand{\@unittext}{#1}}
\newcommand{\units}[1]{\renewcommand{\@units}{#1}}
\newcommand{\textbooks}[1]{\renewcommand{\@textbooks}{#1}}
\newcommand{\policies}[1]{\renewcommand{\@policies}{#1}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% environment/table for course schedules
\newenvironment{schedule}{%
    \begin{longtable}{l l}
}{%
    \end{table}%
}

% Command for use inside schedules for individual days/weeks
\newcommand{\event}[2]{#1 & #2 \\}

% Show the required details at the beginning of the syllabus (no need for
% maketitle).
\AtBeginDocument{%

% Course information
\begin{tabular}{ l l }
  \multirow{3}{*}{\@schoollogo} & \LARGE \@coursenum \\\\
  & \LARGE \textsc{\@coursetitle} \\\\
  & \large \@coursesched \\\\
\end{tabular}
\vspace{10mm}

% Professor information
\begin{tabular}{ l l }
  \multirow{6}{*}{\@profimage} & \large \@profname \\\\
  & \large \url{\@profemail} \\
  & \large \url{\@profwebsite} \\
  & \large Office: \@profoffice \\
  & \large Office Hours: \@profhours \\
  & \large \@profphone \\
\end{tabular}
\vspace{5mm}

\@revisiontext \\

% Course details
\textbf {Course Description:} \@coursedescription \\\\
\textbf {Prerequisite(s):} \@prereqs \\
\ifthenelse{\NOT \isundefined{\@notes}}{\textbf {Note(s):} \@notes \\}{}
\textbf {\@unittext:} \@units \\
\textbf {Text(s):} \@textbooks \\

}

\endinput